####################
Common Usage Patters
####################

Do we have better terms for simple/cained/coupled. I doubt that this will mean anythin to people. 

.. toctree::
   :numbered:

   simple.rst
   chained.rst
   coupled.rst

